@@ -227,15 +227,7 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.mock_get_subnet_from_pool = mock.patch.object(
             ovn_helper.OvnProviderHelper,
             '_get_subnet_from_pool',
-            return_value=(None, None)).start()
-        self.mock_check_ip_in_subnet = mock.patch.object(
-            ovn_helper.OvnProviderHelper,
-            '_check_ip_in_subnet',
-            return_value=True).start()
-
-    def test_check_for_allowed_cidrs_exception(self):
-        self.assertRaises(exceptions.UnsupportedOptionError,
-                          self.driver._check_for_allowed_cidrs, '10.0.0.1')
+            return_value=None).start()
 
     def test__ip_version_differs(self):
         self.assertFalse(self.driver._ip_version_differs(self.ref_member))
@@ -305,18 +297,7 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
 
     def test_member_create_no_subnet_provided_get_from_pool(self):
         self.driver._ovn_helper._get_subnet_from_pool.return_value = (
-            self.ref_member.subnet_id, '198.52.100.0/24')
-        self.driver._ovn_helper._check_ip_in_subnet.return_value = False
-        self.ref_member.subnet_id = data_models.UnsetType()
-        self.assertRaises(exceptions.UnsupportedOptionError,
-                          self.driver.member_create, self.ref_member)
-        self.ref_member.subnet_id = None
-        self.assertRaises(exceptions.UnsupportedOptionError,
-                          self.driver.member_create, self.ref_member)
-
-    def test_member_create_no_subnet_provided_get_from_pool_failed(self):
-        self.driver._ovn_helper._get_subnet_from_pool.return_value = (
-            self.ref_member.subnet_id, '198.52.100.0/24')
+            self.ref_member.subnet_id)
         member = copy.copy(self.ref_member)
         member.subnet_id = data_models.UnsetType()
         self._test_member_create(member)
@@ -362,40 +343,6 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.member_update(self.ref_member, self.update_member)
         self.mock_add_request.assert_called_once_with(expected_dict)
 
-    def test_member_update_missing_subnet_id(self):
-        self.driver._ovn_helper._get_subnet_from_pool.return_value = (
-            self.ref_member.subnet_id, '198.52.100.0/24')
-        info = {'id': self.update_member.member_id,
-                'address': self.ref_member.address,
-                'protocol_port': self.ref_member.protocol_port,
-                'pool_id': self.ref_member.pool_id,
-                'admin_state_up': self.update_member.admin_state_up,
-                'old_admin_state_up': self.ref_member.admin_state_up,
-                'subnet_id': self.ref_member.subnet_id}
-        expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
-                         'info': info}
-        member = copy.copy(self.ref_member)
-        member.subnet_id = data_models.UnsetType()
-        self.driver.member_update(member, self.update_member)
-        self.mock_add_request.assert_called_once_with(expected_dict)
-
-    def test_member_update_unset_admin_state_up(self):
-        self.driver._ovn_helper._get_subnet_from_pool.return_value = (
-            self.ref_member.subnet_id, '198.52.100.0/24')
-        self.update_member.admin_state_up = data_models.UnsetType()
-        info = {'id': self.update_member.member_id,
-                'address': self.ref_member.address,
-                'protocol_port': self.ref_member.protocol_port,
-                'pool_id': self.ref_member.pool_id,
-                'old_admin_state_up': self.ref_member.admin_state_up,
-                'subnet_id': self.ref_member.subnet_id}
-        expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
-                         'info': info}
-        member = copy.copy(self.ref_member)
-        member.subnet_id = data_models.UnsetType()
-        self.driver.member_update(member, self.update_member)
-        self.mock_add_request.assert_called_once_with(expected_dict)
-
     @mock.patch.object(ovn_driver.OvnProviderDriver, '_ip_version_differs')
     def test_member_update_no_ip_addr(self, mock_ip_differs):
         self.update_member.address = None
@@ -441,21 +388,6 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                           self.driver.member_batch_update,
                           self.pool_id, [self.ref_member])
 
-    def test_member_batch_update_missing_subnet_id_get_from_pool(self):
-        self.driver._ovn_helper._get_subnet_from_pool.return_value = (
-            self.ref_member.subnet_id, '198.52.100.0/24')
-        self.ref_member.subnet_id = None
-        self.driver.member_batch_update(self.pool_id, [self.ref_member])
-
-    def test_member_batch_update_missing_subnet_id_get_from_pool_fail(self):
-        self.driver._ovn_helper._get_subnet_from_pool.return_value = (
-            self.ref_member.subnet_id, '198.52.100.0/24')
-        self.driver._ovn_helper._check_ip_in_subnet.return_value = False
-        self.ref_member.subnet_id = None
-        self.assertRaises(exceptions.UnsupportedOptionError,
-                          self.driver.member_batch_update,
-                          self.pool_id, [self.ref_member])
-
     def test_member_update_failure(self):
         self.assertRaises(exceptions.UnsupportedOptionError,
                           self.driver.member_update, self.ref_member,
@@ -490,34 +422,6 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
             mock.call(expected_dict_dvr)]
         self.mock_add_request.assert_has_calls(expected)
 
-    def test_member_delete_missing_subnet_id(self):
-        self.driver._ovn_helper._get_subnet_from_pool.return_value = (
-            self.ref_member.subnet_id, '198.52.100.0/24')
-        info = {'id': self.ref_member.member_id,
-                'address': self.ref_member.address,
-                'protocol_port': self.ref_member.protocol_port,
-                'pool_id': self.ref_member.pool_id,
-                'subnet_id': self.ref_member.subnet_id}
-        expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_DELETE,
-                         'info': info}
-        info_dvr = {
-            'id': self.ref_member.member_id,
-            'address': self.ref_member.address,
-            'pool_id': self.ref_member.pool_id,
-            'subnet_id': self.ref_member.subnet_id,
-            'action': ovn_const.REQ_INFO_MEMBER_DELETED}
-        expected_dict_dvr = {
-            'type': ovn_const.REQ_TYPE_HANDLE_MEMBER_DVR,
-            'info': info_dvr}
-
-        member = copy.copy(self.ref_member)
-        member.subnet_id = data_models.UnsetType()
-        self.driver.member_delete(member)
-        expected = [
-            mock.call(expected_dict),
-            mock.call(expected_dict_dvr)]
-        self.mock_add_request.assert_has_calls(expected)
-
     def test_listener_create(self):
         info = {'id': self.ref_listener.listener_id,
                 'protocol': self.ref_listener.protocol,
@@ -583,31 +487,6 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.listener_update(self.ref_listener, self.ref_listener)
         self.mock_add_request.assert_called_once_with(expected_dict)
 
-    def test_listener_update_unset_admin_state_up(self):
-        self.ref_listener.admin_state_up = data_models.UnsetType()
-        info = {'id': self.ref_listener.listener_id,
-                'protocol_port': self.ref_listener.protocol_port,
-                'protocol': self.ref_pool.protocol,
-                'loadbalancer_id': self.ref_listener.loadbalancer_id}
-        if self.ref_listener.default_pool_id:
-            info['default_pool_id'] = self.ref_listener.default_pool_id
-        expected_dict = {'type': ovn_const.REQ_TYPE_LISTENER_UPDATE,
-                         'info': info}
-        self.driver.listener_update(self.ref_listener, self.ref_listener)
-        self.mock_add_request.assert_called_once_with(expected_dict)
-
-    def test_listener_update_unset_default_pool_id(self):
-        self.ref_listener.default_pool_id = data_models.UnsetType()
-        info = {'id': self.ref_listener.listener_id,
-                'protocol_port': self.ref_listener.protocol_port,
-                'protocol': self.ref_pool.protocol,
-                'admin_state_up': self.ref_listener.admin_state_up,
-                'loadbalancer_id': self.ref_listener.loadbalancer_id}
-        expected_dict = {'type': ovn_const.REQ_TYPE_LISTENER_UPDATE,
-                         'info': info}
-        self.driver.listener_update(self.ref_listener, self.ref_listener)
-        self.mock_add_request.assert_called_once_with(expected_dict)
-
     def test_listener_delete(self):
         info = {'id': self.ref_listener.listener_id,
                 'protocol_port': self.ref_listener.protocol_port,
@@ -686,76 +565,6 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.loadbalancer_create(self.ref_lb0)
         self.mock_add_request.assert_has_calls(calls)
 
-    def test_loadbalancer_create_member_without_subnet_id(self):
-        self.ref_member.subnet_id = data_models.UnsetType()
-        info = {
-            'id': self.ref_lb_fully_populated.loadbalancer_id,
-            'vip_address': self.ref_lb_fully_populated.vip_address,
-            'vip_network_id': self.ref_lb_fully_populated.vip_network_id,
-            'admin_state_up': self.ref_lb_fully_populated.admin_state_up}
-        info_listener = {
-            'id': self.ref_listener.listener_id,
-            'protocol': self.ref_listener.protocol,
-            'protocol_port': self.ref_listener.protocol_port,
-            'default_pool_id': self.ref_listener.default_pool_id,
-            'admin_state_up': self.ref_listener.admin_state_up,
-            'loadbalancer_id': self.ref_listener.loadbalancer_id}
-        info_pool = {
-            'id': self.ref_pool.pool_id,
-            'loadbalancer_id': self.ref_pool.loadbalancer_id,
-            'listener_id': self.ref_pool.listener_id,
-            'protocol': self.ref_pool.protocol,
-            'lb_algorithm': constants.LB_ALGORITHM_SOURCE_IP_PORT,
-            'admin_state_up': self.ref_pool.admin_state_up}
-        info_member = {
-            'id': self.ref_member.member_id,
-            'address': self.ref_member.address,
-            'protocol_port': self.ref_member.protocol_port,
-            'pool_id': self.ref_member.pool_id,
-            'subnet_id': self.ref_lb_fully_populated.vip_network_id,
-            'admin_state_up': self.ref_member.admin_state_up}
-        info_dvr = {
-            'id': self.ref_member.member_id,
-            'address': self.ref_member.address,
-            'pool_id': self.ref_member.pool_id,
-            'subnet_id': self.ref_lb_fully_populated.vip_network_id,
-            'action': ovn_const.REQ_INFO_MEMBER_ADDED}
-        expected_lb_dict = {
-            'type': ovn_const.REQ_TYPE_LB_CREATE,
-            'info': info}
-        expected_listener_dict = {
-            'type': ovn_const.REQ_TYPE_LISTENER_CREATE,
-            'info': info_listener}
-        expected_pool_dict = {
-            'type': ovn_const.REQ_TYPE_POOL_CREATE,
-            'info': info_pool}
-        expected_member_dict = {
-            'type': ovn_const.REQ_TYPE_MEMBER_CREATE,
-            'info': info_member}
-        expected_dict_dvr = {
-            'type': ovn_const.REQ_TYPE_HANDLE_MEMBER_DVR,
-            'info': info_dvr}
-        calls = [mock.call(expected_lb_dict),
-                 mock.call(expected_listener_dict),
-                 mock.call(expected_pool_dict),
-                 mock.call(expected_member_dict),
-                 mock.call(expected_dict_dvr)]
-        self.driver.loadbalancer_create(self.ref_lb_fully_populated)
-        self.mock_add_request.assert_has_calls(calls)
-
-    def test_loadbalancer_create_unset_listeners(self):
-        self.ref_lb0.listeners = data_models.UnsetType()
-        info = {'id': self.ref_lb0.loadbalancer_id,
-                'vip_address': self.ref_lb0.vip_address,
-                'vip_network_id': self.ref_lb0.vip_network_id,
-                'admin_state_up': False}
-        expected_dict = {
-            'type': ovn_const.REQ_TYPE_LB_CREATE,
-            'info': info}
-        calls = [mock.call(expected_dict)]
-        self.driver.loadbalancer_create(self.ref_lb0)
-        self.mock_add_request.assert_has_calls(calls)
-
     def test_loadbalancer_create_unset_admin_state_up(self):
         self.ref_lb0.admin_state_up = data_models.UnsetType()
         info = {'id': self.ref_lb0.loadbalancer_id,
@@ -777,14 +586,6 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.loadbalancer_update(self.ref_lb0, self.ref_lb1)
         self.mock_add_request.assert_called_once_with(expected_dict)
 
-    def test_loadbalancer_update_unset_admin_state_up(self):
-        self.ref_lb1.admin_state_up = data_models.UnsetType()
-        info = {'id': self.ref_lb1.loadbalancer_id}
-        expected_dict = {'type': ovn_const.REQ_TYPE_LB_UPDATE,
-                         'info': info}
-        self.driver.loadbalancer_update(self.ref_lb0, self.ref_lb1)
-        self.mock_add_request.assert_called_once_with(expected_dict)
-
     def test_loadbalancer_delete(self):
         info = {'id': self.ref_lb0.loadbalancer_id,
                 'cascade': False}
@@ -820,32 +621,6 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.pool_create(self.ref_pool)
         self.mock_add_request.assert_called_once_with(expected_dict)
 
-    def test_pool_create_with_health_monitor(self):
-        self.ref_pool.healthmonitor = self.ref_health_monitor
-        info = {'id': self.ref_pool.pool_id,
-                'loadbalancer_id': self.ref_pool.loadbalancer_id,
-                'listener_id': self.ref_pool.listener_id,
-                'protocol': self.ref_pool.protocol,
-                'lb_algorithm': constants.LB_ALGORITHM_SOURCE_IP_PORT,
-                'admin_state_up': self.ref_pool.admin_state_up}
-        info_hm = {'id': self.ref_health_monitor.healthmonitor_id,
-                   'pool_id': self.ref_health_monitor.pool_id,
-                   'type': self.ref_health_monitor.type,
-                   'interval': self.ref_health_monitor.delay,
-                   'timeout': self.ref_health_monitor.timeout,
-                   'failure_count': self.ref_health_monitor.max_retries_down,
-                   'success_count': self.ref_health_monitor.max_retries,
-                   'admin_state_up': self.ref_health_monitor.admin_state_up}
-
-        expected_pool_dict = {'type': ovn_const.REQ_TYPE_POOL_CREATE,
-                              'info': info}
-        expected_hm_dict = {'type': ovn_const.REQ_TYPE_HM_CREATE,
-                            'info': info_hm}
-        calls = [mock.call(expected_pool_dict),
-                 mock.call(expected_hm_dict)]
-        self.driver.pool_create(self.ref_pool)
-        self.mock_add_request.assert_has_calls(calls)
-
     def test_pool_create_unset_admin_state_up(self):
         self.ref_pool.admin_state_up = data_models.UnsetType()
         info = {'id': self.ref_pool.pool_id,
@@ -870,31 +645,24 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.pool_delete(self.ref_pool)
         self.mock_add_request.assert_called_once_with(expected)
 
-    def test_pool_delete_with_members_and_hm(self):
-        self.ref_pool.healthmonitor = self.ref_health_monitor
+    def test_pool_delete_with_members(self):
         info = {'id': self.ref_pool.pool_id,
                 'protocol': self.ref_pool.protocol,
                 'loadbalancer_id': self.ref_pool.loadbalancer_id}
         expected = {'type': ovn_const.REQ_TYPE_POOL_DELETE,
                     'info': info}
-        info_hm = {'id': self.ref_pool.healthmonitor.healthmonitor_id,
-                   'pool_id': self.ref_pool.pool_id}
         info_member = {'id': self.ref_member.member_id,
                        'pool_id': self.ref_member.pool_id,
                        'subnet_id': self.ref_member.subnet_id,
                        'protocol_port': self.ref_member.protocol_port,
                        'address': self.ref_member.address}
-        expected_hm = {
-            'type': ovn_const.REQ_TYPE_HM_DELETE,
-            'info': info_hm}
         expected_members = {
             'type': ovn_const.REQ_TYPE_MEMBER_DELETE,
             'info': info_member}
         expected_members_dvr = {
             'type': ovn_const.REQ_TYPE_HANDLE_MEMBER_DVR,
             'info': mock.ANY}
-        calls = [mock.call(expected_hm),
-                 mock.call(expected_members),
+        calls = [mock.call(expected_members),
                  mock.call(expected_members_dvr),
                  mock.call(expected)]
         self.driver.pool_delete(self.ref_pool)
@@ -910,38 +678,6 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.pool_update(self.ref_pool, self.ref_update_pool)
         self.mock_add_request.assert_called_once_with(expected_dict)
 
-    def test_pool_update_unset_new_protocol(self):
-        self.ref_update_pool.protocol = data_models.UnsetType()
-        info = {'id': self.ref_update_pool.pool_id,
-                'loadbalancer_id': self.ref_update_pool.loadbalancer_id,
-                'protocol': self.ref_pool.protocol,
-                'admin_state_up': self.ref_update_pool.admin_state_up}
-        expected_dict = {'type': ovn_const.REQ_TYPE_POOL_UPDATE,
-                         'info': info}
-        self.driver.pool_update(self.ref_pool, self.ref_update_pool)
-        self.mock_add_request.assert_called_once_with(expected_dict)
-
-    def test_pool_update_unset_new_lb_algorithm(self):
-        self.ref_update_pool.lb_algorithm = data_models.UnsetType()
-        info = {'id': self.ref_update_pool.pool_id,
-                'loadbalancer_id': self.ref_update_pool.loadbalancer_id,
-                'protocol': self.ref_pool.protocol,
-                'admin_state_up': self.ref_update_pool.admin_state_up}
-        expected_dict = {'type': ovn_const.REQ_TYPE_POOL_UPDATE,
-                         'info': info}
-        self.driver.pool_update(self.ref_pool, self.ref_update_pool)
-        self.mock_add_request.assert_called_once_with(expected_dict)
-
-    def test_pool_update_unset_new_admin_state_up(self):
-        self.ref_update_pool.admin_state_up = data_models.UnsetType()
-        info = {'id': self.ref_update_pool.pool_id,
-                'loadbalancer_id': self.ref_update_pool.loadbalancer_id,
-                'protocol': self.ref_pool.protocol}
-        expected_dict = {'type': ovn_const.REQ_TYPE_POOL_UPDATE,
-                         'info': info}
-        self.driver.pool_update(self.ref_pool, self.ref_update_pool)
-        self.mock_add_request.assert_called_once_with(expected_dict)
-
     def test_create_vip_port(self):
         with mock.patch.object(clients, 'get_neutron_client'):
             port_dict = self.driver.create_vip_port(self.loadbalancer_id,
@@ -1050,8 +786,7 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.mock_add_request.assert_called_once_with(expected_dict)
 
     def test_health_monitor_delete(self):
-        info = {'id': self.ref_health_monitor.healthmonitor_id,
-                'pool_id': self.ref_health_monitor.pool_id}
+        info = {'id': self.ref_health_monitor.healthmonitor_id}
         expected_dict = {'type': ovn_const.REQ_TYPE_HM_DELETE,
                          'info': info}
         self.driver.health_monitor_delete(self.ref_health_monitor)
